@@ -65,8 +65,12 @@ class Predicate:
 class Filter:
     """Alternative SQL WHERE clause"""
 
-    def __init__(self, preds):
+    OR = ' OR '
+    AND = ' AND '
+
+    def __init__(self, preds, op=AND):
         self.preds = preds
+        self.op = op
         self.values = ()
         for pred in self.preds:
             self.values += pred.values
@@ -75,7 +79,10 @@ class Filter:
         pred_list = []
         for pred in self.preds:
             pred_list.append(pred.render(placeholder))
-        return ' AND '.join(pred_list)
+        result = self.op.join(pred_list)
+        if self.op == Filter.OR:
+            return f'({result})'
+        return result
 
 
 class Order:
@@ -292,6 +299,8 @@ class Query:
                 values += stage.values
                 if isinstance(prev, Aggregation):
                     keyword = 'HAVING'
+                elif isinstance(prev, Filter):
+                    keyword = 'AND'
                 else:
                     keyword = 'WHERE'
                 query = f'{query} {keyword} {text}'
