@@ -120,6 +120,9 @@ class SqlStorage:
             ]
             sco_type = self.table_type(tvname)
             for col in self.schema(tvname):
+                # Don't aggregate the column we used for grouping
+                if col['name'] == groupby:
+                    continue
                 agg = auto_agg(sco_type, col['name'], col['type'])
                 if agg:
                     aggs.append(agg)
@@ -229,13 +232,17 @@ class SqlStorage:
         """Cache the result of a query"""
         logger.debug('Caching %s', query_id)
 
+        if not isinstance(bundles, list):
+            bundles = [bundles]
+
         writer = self._get_writer(str(query_id))
         splitter = SplitWriter(writer, batchsize=1000, query_id=str(query_id))
 
         # walk the bundles and figure out all the columns
-        for filename in bundles:
-            logger.debug('- Caching %s', filename)
-            for obj in _transform(STIX_TRANSFORMS, filename):
+        for bundle in bundles:
+            if isinstance(bundle, str):
+                logger.debug('- Caching %s', bundle)
+            for obj in _transform(STIX_TRANSFORMS, bundle):
                 splitter.write(obj)
         splitter.close()
 
@@ -492,6 +499,20 @@ class SqlStorage:
             return res['appdata']
         return res[0]
 
+    def get_view_data(self, viewnames=None):
+        """Retrieve information about one or more viewnames"""
+        if viewnames:
+            placeholders = ', '.join([self.placeholder] * len(viewnames))
+            stmt = f'SELECT * FROM "__symtable" WHERE name IN ({placeholders});'
+            values = tuple(viewnames)
+        else:
+            stmt = f'SELECT * FROM "__symtable";'
+            values = None
+        cursor = self._query(stmt, values)
+        res = cursor.fetchall()
+        cursor.close()
+        return res
+
     def run_query(self, query):
         query_text, query_values = query.render(self.placeholder)
         return self._query(query_text, query_values)
@@ -511,3 +532,24 @@ class SqlStorage:
         cursor = self._create_view(viewname, stmt, sco_type, deps=input_views)
         self.connection.commit()
         cursor.close()
+
+    def remove_view(self, viewname):
+        """Remove view `viewname`"""
+        validate_name(viewname)
+        cursor = self._execute('BEGIN;')
+        self._execute(f'DROP VIEW IF EXISTS "{viewname}";', cursor)
+        self._drop_name(cursor, viewname)
+        self.connection.commit()
+        cursor.close()
+
+    def rename_view(self, oldname, newname):
+        """Rename view `oldname` to `newname`"""
+        validate_name(oldname)
+        validate_name(newname)
+        view_type = self.table_type(oldname)
+        cursor = self._execute('BEGIN;')
+        self._execute(f'ALTER VIEW "{oldname}" RENAME TO "{newname}";', cursor)
+        self._drop_name(cursor, oldname)
+        self._new_name(cursor, newname, view_type)
+        self.connection.commit()
+        cursor.close()
