@@ -6,13 +6,31 @@ import pytest
 from collections import Counter
 
 from firepit.exceptions import IncompatibleType
+from firepit.exceptions import UnknownViewname
 
 from .helpers import tmp_storage
 
 
-def test_local(fake_bundle_file, fake_csv_file, tmpdir):
+def test_local(fake_bundle_file, tmpdir):
     store = tmp_storage(tmpdir)
-    store.cache('q1', [fake_bundle_file])
+    store.cache('q1', fake_bundle_file)
+
+    store.extract('urls', 'url', 'q1', "[url:value LIKE '%page/1%']")
+    urls = store.values('url:value', 'urls')
+    print(urls)
+    assert len(urls) == 14
+    assert 'http://www8.example.com/page/176' in urls
+    assert 'http://www27.example.com/page/64' not in urls
+
+    store.delete()
+
+
+def test_in_memory(fake_bundle_file, tmpdir):
+    with open(fake_bundle_file, 'r') as fp:
+        bundle = json.loads(fp.read())
+
+    store = tmp_storage(tmpdir)
+    store.cache('q1', bundle)
 
     store.extract('urls', 'url', 'q1', "[url:value LIKE '%page/1%']")
     urls = store.values('url:value', 'urls')
@@ -76,7 +94,11 @@ def test_basic(fake_bundle_file, fake_csv_file, tmpdir):
     counter = Counter(users)
     assert counter['henry'] == 2
     assert counter['isabel'] == 12
-    store.assign('grouped_users', 'users', op='group', by='user-account:account_login')
+    by = 'user-account:account_login'
+    store.assign('grouped_users', 'users', op='group', by=by)
+    cols = store.columns('grouped_users')
+    _, _, by = by.rpartition(':')
+    assert f'unique_{by}' not in cols
     grouped_users = store.lookup('grouped_users')
     print(grouped_users)
     henry = next((item for item in grouped_users if item['account_login'] == 'henry'), None)
@@ -288,6 +310,25 @@ def test_appdata(fake_bundle_file, tmpdir):
     assert len(result) == len(data)
 
 
+def test_viewdata(fake_bundle_file, tmpdir):
+    store = tmp_storage(tmpdir)
+    store.cache('q1', [fake_bundle_file])
+    store.extract('ssh_conns', 'network-traffic', 'q1', "[network-traffic:dst_port = 22]")
+    ssh_data = {'foo': 99}
+    store.set_appdata('ssh_conns', json.dumps(ssh_data))
+    store.extract('dns_conns', 'network-traffic', 'q1', "[network-traffic:dst_port = 53]")
+    dns_data = {'bar': 98}
+    store.set_appdata('dns_conns', json.dumps(dns_data))
+
+    results = store.get_view_data(['ssh_conns', 'dns_conns'])
+    assert len(results) == 2
+    for result in results:
+        if result['name'] == 'ssh_conns':
+            assert ssh_data == json.loads(result['appdata'])
+        else:
+            assert dns_data == json.loads(result['appdata'])
+
+
 def test_duplicate(fake_bundle_file, tmpdir):
     store = tmp_storage(tmpdir)
 
@@ -355,3 +396,39 @@ def test_change_type(fake_bundle_file, tmpdir):
     # sqlite3 doesn't have issues with this; only PostgreSQL
     with pytest.raises(IncompatibleType):
         store.extract('foo', 'ipv4-addr', 'q1', "[ipv4-addr:value ISSUBSET '192.168.0.0/16']")
+
+
+def test_remove(fake_bundle_file, tmpdir):
+    store = tmp_storage(tmpdir)
+    store.cache('q1', fake_bundle_file)
+
+    store.extract('urls1', 'url', 'q1', "[url:value LIKE '%page/1%']")
+    urls1 = store.lookup('urls1')
+    assert len(urls1) == 14
+
+    store.extract('urls2', 'url', 'q1', "[url:value LIKE '%page/2%']")
+    urls2 = store.lookup('urls2')
+    assert len(urls2)
+
+    store.remove_view('urls1')
+    with pytest.raises(UnknownViewname):
+        store.lookup('urls1')
+
+    urls2 = store.lookup('urls2')
+    assert len(urls2)
+
+
+def test_rename(fake_bundle_file, tmpdir):
+    store = tmp_storage(tmpdir)
+    store.cache('q1', fake_bundle_file)
+
+    store.extract('urls1', 'url', 'q1', "[url:value LIKE '%page/1%']")
+    urls1 = store.lookup('urls1')
+    assert len(urls1) == 14
+
+    store.rename_view('urls1', 'urls2')
+    with pytest.raises(UnknownViewname):
+        store.lookup('urls1')
+
+    urls2 = store.lookup('urls2')
+    assert len(urls2) == 14
